import java.nio.*;

class Benchmark {
  interface Test {
    public void runOnce();
  }
  
  class TestArrayReallocate implements Test {
    public void runOnce()
    {
      int[] test=new int[6];
      int result=Interface.add_array_array(test);
    }
  }

  class TestArrayAllocateOnce implements Test {
    public int[] test;
    
    public TestArrayAllocateOnce()
    {
      test=new int[6];
    }
    
    public void runOnce()
    {
      int result=Interface.add_array_array(test);
    }
  }

  class TestByteBufferReallocate implements Test {
    public void runOnce()
    {
      IntBuffer intBuffer=ByteBuffer.allocateDirect(24).asIntBuffer();
      int result=Interface.add_array_IntBuffer(intBuffer);
    }
  }

  class TestByteBufferAllocateOnce implements Test {
    public IntBuffer intBuffer;
    
    public TestByteBufferAllocateOnce()
    {
      intBuffer=ByteBuffer.allocateDirect(24).asIntBuffer();
    }
    
    public void runOnce()
    {
      int result=Interface.add_array_IntBuffer(intBuffer);
    }
  }

  public static void runTest(int repetitions, Test test)
  {
    System.out.println("running Test " + test.getClass().getName() + " for " + repetitions + " times");
    long startTime, endTime;
    startTime=System.currentTimeMillis();

    for(int i=0;i<repetitions;i++) {
      test.runOnce();
    }

    endTime=System.currentTimeMillis();
    System.out.println("result: " + (endTime-startTime));
  }

  Benchmark()
  {
    int repetitions=1000000;
    runTest(repetitions,new TestArrayReallocate());
    runTest(repetitions,new TestArrayAllocateOnce());
    runTest(repetitions,new TestByteBufferReallocate());
    runTest(repetitions,new TestByteBufferAllocateOnce());
  }

  public static void main(String[] args)
  {
    System.loadLibrary("Interface");
    new Benchmark();
  }
};